@@ -2,5 +2,4 @@
 ;;; For more information see (info "(emacs) Directory Variables")
 
 ((nil . ((indent-tabs-mode . nil)))
- (emacs-lisp-mode . ((elisp-flymake-byte-compile-load-path . load-path)
-                     (package-lint-main-file . "mastodon.el"))))
+ (emacs-lisp-mode . ((package-lint-main-file . "mastodon.el"))))
